@@ -71,7 +71,7 @@ Restrictions:
     100%. Remembercomparing two straight lines yields 100% polarisation.
 
 """
-
+import logging
 import warnings
 import numpy as np
 from pytplot import get_data, store_data, options
@@ -79,8 +79,8 @@ from pyspedas import tnames
 
 # these routines require numpy v1.20.0 or later
 if np.__version__ < '1.20':
-    print('Error: numpy 1.20.0 or later is required for wave polarization calculations. ')
-    print('Please update numpy with: pip install numpy --upgrade')
+    logging.error('Error: numpy 1.20.0 or later is required for wave polarization calculations. ')
+    logging.error('Please update numpy with: pip install numpy --upgrade')
     breakpoint()
 
 
@@ -319,10 +319,9 @@ def wavpol(ct, bx, by, bz,
     endsampfreq = 1./(ct[nopoints-1]-ct[nopoints-2])
 
     if beginsampfreq != endsampfreq:
-        print('wavpol Warning: file sampling frequency changes from ',
-              beginsampfreq, 'Hz to ', endsampfreq, 'Hz')
+        logging.warning('wavpol Warning: file sampling frequency changes from ' + str(beginsampfreq) + 'Hz to ' + str(endsampfreq) + 'Hz')
     else:
-        print('wavpol: File sampling frequency=', beginsampfreq, 'Hz')
+        logging.warning('wavpol: File sampling frequency=' + str(beginsampfreq) + 'Hz')
 
     samp_freq = beginsampfreq
     samp_per = 1./samp_freq
@@ -352,7 +351,7 @@ def wavpol(ct, bx, by, bz,
 
     # If there are too many batches, return.
     if n_batches > 80000.0:
-        print("wavpol error: Large number of batches. " +
+        logging.error("wavpol error: Large number of batches. " +
               "Returning to avoid memory runaway.")
         err_flag = 1
         result = (timeline, freqline, powspec, degpol, waveangle,
@@ -363,14 +362,14 @@ def wavpol(ct, bx, by, bz,
     # Total numbers of FFT calculations including 1 leap frog for each batch
     ind_batch0 = 0
     nosteps = 0
-    print('n_batches', n_batches)
+    logging.info('n_batches: ' + str(n_batches))
 
     for i in range(n_batches):
         nosteps = int(nosteps + np.floor((errs[i] - ind_batch0)/steplength))
         ind_batch0 = errs[i]
 
     nosteps = nosteps + n_batches
-    print('Total number of steps:', nosteps)
+    logging.info('Total number of steps:' + str(nosteps))
 
     # leveltplot = 0.000001  # Power rejection level 0 to 1
     nosmbins = bin_freq  # No. of bins in frequency domain
@@ -426,8 +425,7 @@ def wavpol(ct, bx, by, bz,
         ngood = np.count_nonzero(~np.isnan(xs))  # Count finite data.
         if ngood > nopfft:
             nbp_fft_batches[batch] = np.floor(ngood/steplength)
-            print('Total number of possible FFT in the batch no ', batch,
-                  ' is:', nbp_fft_batches[batch])
+            logging.info('Total number of possible FFT in the batch no ' + str(batch) + ' is:' + str(nbp_fft_batches[batch]))
             ind0_fft = 0
             for j in range(int(nbp_fft_batches[batch])):
                 # ind1_fft = nopfft * (j+1)-1
@@ -574,8 +572,7 @@ def wavpol(ct, bx, by, bz,
 
                 # Print an indication that a computation is happening.
                 if KK == 0 or KK % 40 == 0:
-                    print(' ')
-                    print('wavpol step', KK, ' ', end='')
+                    logging.info('wavpol step: ' + str(KK) + ' ')
                 elif KK % 4 == 0:
                     print('.', end='')
 
@@ -598,9 +595,9 @@ def wavpol(ct, bx, by, bz,
             # End "if ngood > nopfft"
         else:
             binwidth = samp_freq/nopfft
-            print('Fourier Transform is not possible. ',
-                  'Ngood = ', ngood,
-                  'Required number of points for FFT = ', nopfft)
+            logging.error('Fourier Transform is not possible. ')
+            logging.error('Ngood = ' + str(ngood))
+            logging.error('Required number of points for FFT = ' + str(nopfft))
 
             timeline[KK] = (ct[ind0] +
                             np.abs(int(nopfft/2))/samp_freq +
@@ -627,7 +624,7 @@ def wavpol(ct, bx, by, bz,
     # Returns results.
     result = (timeline, freqline, powspec, degpol, waveangle,
               elliptict, helict, pspec3, err_flag)
-    print('\nwavpol completed successfully')
+    logging.info('\nwavpol completed successfully')
 
     return result
 
@@ -664,25 +661,25 @@ def twavpol(tvarname, prefix='', nopfft=-1, steplength=-1, bin_freq=-1):
 
     all_names = tnames(tvarname)
     if len(all_names) < 1:
-        print('twavpol error: No valid pytplot variables match tvarname.')
+        logging.error('twavpol error: No valid pytplot variables match tvarname.')
         return 0
 
     xdata = get_data(tvarname)
 
     ct = xdata.times
     if len(ct) < 2:
-        print('twavpol error: Time variable does not have enough points.')
+        logging.error('twavpol error: Time variable does not have enough points.')
         return 0
 
     bfield = xdata.y
     if bfield.ndim != 2:
-        print('twavpol error: Data should have 2 dimensions.')
+        logging.error('twavpol error: Data should have 2 dimensions.')
         return 0
     b1 = bfield[:, 0]
     b2 = bfield[:, 1]
     b3 = bfield[:, 2]
     if (len(ct) != len(b1) or len(ct) != len(b2) or len(ct) != len(b3)):
-        print('twavpol error: Number of time elements does not match' +
+        logging.error('twavpol error: Number of time elements does not match' +
               'number of magnetic field elements.')
         return 0
 
@@ -693,7 +690,7 @@ def twavpol(tvarname, prefix='', nopfft=-1, steplength=-1, bin_freq=-1):
                                         bin_freq=bin_freq)
 
     if err_flag == 1:
-        print('twavpol error: There were errors while applying wavpol.')
+        logging.error('twavpol error: There were errors while applying wavpol.')
         return 0
 
     # Store new pytplot variables as spectrograms.
